==> docx4j-openxml-objects-8.0.0-sources.jar: org/docx4j/dml/diagram/STBreakpoint.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml.diagram;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_Breakpoint.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_Breakpoint">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token">
 *     &lt;enumeration value="endCnv"/>
 *     &lt;enumeration value="bal"/>
 *     &lt;enumeration value="fixed"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ST_Breakpoint")
@XmlEnum
public enum STBreakpoint {


    /**
     * End of Canvas
     * 
     */
    @XmlEnumValue("endCnv")
    END_CNV("endCnv"),

    /**
     * Balanced
     * 
     */
    @XmlEnumValue("bal")
    BAL("bal"),

    /**
     * Fixed
     * 
     */
    @XmlEnumValue("fixed")
    FIXED("fixed");
    private final String value;

    STBreakpoint(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STBreakpoint fromValue(String v) {
        for (STBreakpoint c: STBreakpoint.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> docx4j-openxml-objects-8.1.6-sources.jar: org/docx4j/dml/diagram/STBreakpoint.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml.diagram;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_Breakpoint.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_Breakpoint"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token"&gt;
 *     &lt;enumeration value="endCnv"/&gt;
 *     &lt;enumeration value="bal"/&gt;
 *     &lt;enumeration value="fixed"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ST_Breakpoint")
@XmlEnum
public enum STBreakpoint {


    /**
     * End of Canvas
     * 
     */
    @XmlEnumValue("endCnv")
    END_CNV("endCnv"),

    /**
     * Balanced
     * 
     */
    @XmlEnumValue("bal")
    BAL("bal"),

    /**
     * Fixed
     * 
     */
    @XmlEnumValue("fixed")
    FIXED("fixed");
    private final String value;

    STBreakpoint(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STBreakpoint fromValue(String v) {
        for (STBreakpoint c: STBreakpoint.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
